# Generated by Django 3.1.2 on 2021-04-13 18:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0015_add_aka_longname"),
    ]

    operations = [
        migrations.AddField(
            model_name="internetexchange",
            name="service_level",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "Not Disclosed"),
                    ("Not Disclosed", "Not Disclosed"),
                    ("Best Effort (no SLA)", "Best Effort (no SLA)"),
                    ("Normal Business Hours", "Normal Business Hours"),
                    ("24/7 Support", "24/7 Support"),
                ],
                default="Not Disclosed",
                max_length=60,
                verbose_name="Service Level",
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="terms",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "Not Disclosed"),
                    ("Not Disclosed", "Not Disclosed"),
                    ("No Commercial Terms", "No Commercial Terms"),
                    ("Bundled With Other Services", "Bundled With Other Services"),
                    ("Non-recurring Fees Only", "Non-recurring Fees Only"),
                    ("Recurring Fees", "Recurring Fees"),
                ],
                default="Not Disclosed",
                max_length=60,
                verbose_name="Terms",
            ),
        ),
    ]



# Generated by Django 2.2.12 on 2020-05-21 06:05

from django.db import migrations, models


def adjust_traffic_levels(apps, schema_editor):
    Network = apps.get_model("django_peeringdb", "Network")

    for net in Network.handleref.all():

        # only save networks that actually had to have their value
        # adjusted

        save = False

        # remove spaces

        if net.info_traffic.find(" ") > -1:
            net.info_traffic = net.info_traffic.replace(" ", "")
            save = True

        # replace values

        if net.info_traffic == "100+Gbps":
            net.info_traffic = "100-200Gbps"
            save = True

        elif net.info_traffic == "1Tbps+":
            net.info_traffic = "1-5Tbps"
            save = True

        elif net.info_traffic == "10Tbps+":
            net.info_traffic = "10-20Tbps"
            save = True

        if save:
            net.save()


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0007_add_verbose_names"),
    ]

    operations = [
        migrations.RunPython(adjust_traffic_levels),
        migrations.AlterField(
            model_name="network",
            name="info_traffic",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "Not Disclosed"),
                    ("0-20Mbps", "0-20Mbps"),
                    ("20-100Mbps", "20-100Mbps"),
                    ("100-1000Mbps", "100-1000Mbps"),
                    ("1-5Gbps", "1-5Gbps"),
                    ("5-10Gbps", "5-10Gbps"),
                    ("10-20Gbps", "10-20Gbps"),
                    ("20-50Gbps", "20-50Gbps"),
                    ("50-100Gbps", "50-100Gbps"),
                    ("100-200Gbps", "100-200Gbps"),
                    ("200-300Gbps", "200-300Gbps"),
                    ("300-500Gbps", "300-500Gbps"),
                    ("500-1000Gbps", "500-1000Gbps"),
                    ("1-5Tbps", "1-5Tbps"),
                    ("5-10Tbps", "5-10Tbps"),
                    ("10-20Tbps", "10-20Tbps"),
                    ("20-50Tbps", "20-50Tbps"),
                    ("50-100Tbps", "50-100Tbps"),
                    ("100+Tbps", "100+Tbps"),
                ],
                max_length=39,
            ),
        ),
    ]



# Generated by Django 2.2.12 on 2020-04-03 20:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0005_fac_contacts"),
    ]

    operations = [
        migrations.AddField(
            model_name="networkixlan",
            name="operational",
            field=models.BooleanField(default=True),
        ),
    ]



# PeeringDB client backend implementation module

import calendar
import re
from collections import defaultdict
from decimal import Decimal
from ipaddress import IPv4Address, IPv6Address

from django.core.exceptions import ObjectDoesNotExist, ValidationError
from django.core.management import call_command
from django.db import DEFAULT_DB_ALIAS, IntegrityError, connection, connections, models
from django.db.migrations.executor import MigrationExecutor
from django.db.transaction import atomic as atomic_transaction
from django_countries.fields import Country
from peeringdb import resource
from peeringdb.backend import Interface, reftag_to_cls

from django_peeringdb import __version__  # noqa
from django_peeringdb.models import concrete


class Backend(Interface):

    # Non-builtin scalar types
    CUSTOM_FIELDS = (
        Decimal,
        Country,
        IPv4Address,
        IPv6Address,
    )

    # Resource (abstract) and model (concrete) definitions
    RESOURCE_MAP = {
        resource.Facility: concrete.Facility,
        resource.InternetExchange: concrete.InternetExchange,
        resource.InternetExchangeFacility: concrete.InternetExchangeFacility,
        resource.InternetExchangeLan: concrete.IXLan,
        resource.InternetExchangeLanPrefix: concrete.IXLanPrefix,
        resource.Network: concrete.Network,
        resource.NetworkContact: concrete.NetworkContact,
        resource.NetworkFacility: concrete.NetworkFacility,
        resource.NetworkIXLan: concrete.NetworkIXLan,
        resource.Organization: concrete.Organization,
    }

    ERROR_PATTERNS = {
        "mysql": {
            "unique": [(r"Duplicate entry '[^\']+' for key '(?P<field_name>\w+)'", 1)],
        },
        "sqlite": {
            "unique": [
                (r"UNIQUE constraint failed: (\w+)\.(?P<field_name>\w+)", 0),
                (r"column (?P<field_name>\w+) is not unique", 0),
            ],
        },
    }

    @classmethod
    def setup(cls):
        # in order to copy updated / created times from server
        # we need to turn off auto updating of those fields
        # during update and add
        for model in concrete.all_models:
            for field in model._meta.fields:
                if field.name in ["created", "updated"]:
                    field.auto_now_add = False
                    field.auto_now = False

    @classmethod
    def atomic_transaction(cls):
        return atomic_transaction()

    @classmethod
    def validation_error(cls, concrete=None):
        return ValidationError

    @classmethod
    def object_missing_error(cls, concrete=None):
        if concrete:
            return concrete.DoesNotExist
        return ObjectDoesNotExist

    @reftag_to_cls
    def last_change(self, concrete):
        upd = concrete.handleref.last_change()
        if upd:
            return int(calendar.timegm(upd.timetuple()))
        return 0

    @reftag_to_cls
    def get_object(self, concrete, id):
        return concrete.objects.get(pk=id)

    @reftag_to_cls
    def get_object_by(self, concrete, field_name, value):
        return concrete.objects.get(**{field_name: value})

    @reftag_to_cls
    def get_objects(self, concrete, ids=None):
        if ids:
            return concrete.objects.filter(pk__in=ids)
        return concrete.objects.all()

    @reftag_to_cls
    def get_objects_by(self, concrete, field_name, value):
        return concrete.objects.filter(**{field_name: value})

    @reftag_to_cls
    def create_object(self, concrete, **data):
        return concrete.objects.create(**data)

    @reftag_to_cls
    def get_fields(self, concrete):
        return concrete._meta.get_fields()

    @reftag_to_cls
    def get_field(self, concrete, field_name):
        return concrete._meta.get_field(field_name)

    @reftag_to_cls
    def get_field_concrete(self, concrete, field_name):
        return concrete._meta.get_field(field_name).related_model

    @reftag_to_cls
    def is_field_related(self, concrete, field_name):
        field = self.get_field(concrete, field_name)
        related = getattr(field, "related_model", False)
        multiple = getattr(field, "multiple", False)
        return (related, multiple)

    def set_relation_many_to_many(self, obj, field_name, objs):
        "Set a many-to-many field on an object"
        relation = getattr(obj, field_name)
        if hasattr(relation, "set"):
            relation.set(objs)  # Django 2.x
        else:
            setattr(obj, field_name, objs)  # Django 1.x

    def clean(self, obj):
        obj.full_clean()

    def save(self, obj):
        obj.save()

    def convert_field(self, concrete, field_name, value):
        field = concrete._meta.get_field(field_name)
        if isinstance(field, models.DecimalField) and isinstance(value, float):
            return Decimal("{:.{prec}f}".format(value, prec=field.decimal_places))
        else:
            return value

    def detect_missing_relations(self, obj, exc):
        """
        Parse error messages and collect the missing-relationship errors
        as a dict of Resource -> {id set}
        """
        missing = defaultdict(set)
        for name, err in list(exc.error_dict.items()):
            # check if it was a relationship that doesnt exist locally
            pattern = r".+ with id (\d+) does not exist.+"
            m = re.match(pattern, str(err))
            if m:
                field = obj._meta.get_field(name)
                res = self.get_resource(field.related_model)
                missing[res].add(int(m.group(1)))
        return missing

    def detect_uniqueness_error(self, exc):
        """
        Parse error, and if it describes any violations of a uniqueness constraint,
        return the corresponding fields, else None
        """
        pattern = r"(\w+) with this (\w+) already exists"

        fields = []
        if isinstance(exc, IntegrityError):
            return self._detect_integrity_error(exc)
        assert isinstance(exc, ValidationError), TypeError

        for name, err in list(exc.error_dict.items()):
            if re.search(pattern, str(err)):
                fields.append(name)
        return fields or None

    def _detect_integrity_error(self, exc):

        engine = connection.vendor
        patterns = self.ERROR_PATTERNS[engine]

        assert isinstance(exc, IntegrityError)
        # for name, err in exc.error_dict.items():
        for pattern, index in patterns.get("unique"):
            m = re.search(pattern, str(exc.args[index]))
            if m:
                return [m.groupdict()["field_name"]]
        return None

    # Database
    def migrate_database(self, verbosity=0):
        call_command("migrate", interactive=False, verbosity=verbosity)

    # credit to https://stackoverflow.com/a/31847406/1325447
    def is_database_migrated(self, database=DEFAULT_DB_ALIAS):
        connection = connections[database]
        connection.prepare_database()
        executor = MigrationExecutor(connection)
        targets = executor.loader.graph.leaf_nodes()
        # No plan <=> Yes sync'd
        return not executor.migration_plan(targets)

    def delete_all(self):
        call_command("flush", interactive=False, verbosity=1)



# Generated by Django 3.1.2 on 2020-10-06 17:37

import django.db.models.deletion
import django_countries.fields
import django_inet.models
from django.db import migrations, models

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0011_ixlan_ixf_fields"),
    ]

    operations = [
        migrations.AlterField(
            model_name="network",
            name="info_prefixes4",
            field=models.PositiveIntegerField(
                blank=True,
                help_text="Recommended maximum number of IPv4 routes/prefixes to be configured on peering sessions for this ASN",
                null=True,
                verbose_name="IPv4 Prefixes",
            ),
        ),
        migrations.AlterField(
            model_name="network",
            name="info_prefixes6",
            field=models.PositiveIntegerField(
                blank=True,
                help_text="Recommended maximum number of IPv6 routes/prefixes to be configured on peering sessions for this ASN",
                null=True,
                verbose_name="IPv6 Prefixes",
            ),
        ),
        migrations.AlterField(
            model_name="network",
            name="info_type",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "Not Disclosed"),
                    ("Not Disclosed", "Not Disclosed"),
                    ("NSP", "NSP"),
                    ("Content", "Content"),
                    ("Cable/DSL/ISP", "Cable/DSL/ISP"),
                    ("Enterprise", "Enterprise"),
                    ("Educational/Research", "Educational/Research"),
                    ("Non-Profit", "Non-Profit"),
                    ("Route Server", "Route Server"),
                    ("Network Services", "Network Services"),
                    ("Route Collector", "Route Collector"),
                    ("Government", "Government"),
                ],
                default="Not Disclosed",
                max_length=60,
                verbose_name="Network Type",
            ),
        ),
    ]



# Generated by Django 1.11.23 on 2019-12-10 12:12


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0002_network_fields_help_text"),
    ]

    operations = [
        migrations.AddField(
            model_name="network",
            name="info_never_via_route_servers",
            field=models.BooleanField(
                default=False,
                help_text="Indicates if this network will announce its routes via route servers or not",
            ),
        ),
    ]



# Generated by Django 3.2.9 on 2022-02-02 13:59

import django.core.validators
import django_inet.models
from django.db import migrations, models

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0019_ix_add_sales_phone_email"),
    ]

    operations = [
        migrations.AddField(
            model_name="facility",
            name="status_dashboard",
            field=django_peeringdb.models.abstract.URLField(
                blank=True, max_length=255, null=True, verbose_name="Status Dashboard"
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="status_dashboard",
            field=django_peeringdb.models.abstract.URLField(
                blank=True, max_length=255, null=True, verbose_name="Status Dashboard"
            ),
        ),
        migrations.AddField(
            model_name="network",
            name="status_dashboard",
            field=django_peeringdb.models.abstract.URLField(
                blank=True, max_length=255, null=True, verbose_name="Status Dashboard"
            ),
        ),
    ]



# Generated by Django 3.2.7 on 2021-09-07 13:34

import django.core.validators
import django.db.models.deletion
import django_countries.fields
import django_inet.models
from django.db import migrations, models

import django_peeringdb.fields
import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0016_add_ix_service_and_terms"),
    ]

    operations = [
        migrations.AddField(
            model_name="facility",
            name="available_voltage_services",
            field=django_peeringdb.fields.MultipleChoiceField(
                blank=True,
                choices=[
                    ("48 VDC", "48 VDC"),
                    ("120 VAC", "120 VAC"),
                    ("208 VAC", "208 VAC"),
                    ("240 VAC", "240 VAC"),
                    ("480 VAC", "480 VAC"),
                ],
                help_text="The alternating current voltage available to users of the facility either directly from the landlord or delivered by the utility separately.",
                max_length=255,
                null=True,
                verbose_name="Available Voltage Services",
            ),
        ),
        migrations.AddField(
            model_name="facility",
            name="diverse_serving_substations",
            field=models.BooleanField(
                blank=True,
                help_text="Two separate and distinct paths to individual substations which should maintain a separated path back to one or more utility generator stations.",
                null=True,
                verbose_name="Diverse Serving Substations",
            ),
        ),
        migrations.AddField(
            model_name="facility",
            name="property",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "Not Disclosed"),
                    ("Owner", "Owner"),
                    ("Lessee", "Lessee"),
                ],
                help_text="A property owner is the individual or entity that has title to the property. A lessee is a user of a property who has a lease, an agreement, with the owner of the property.",
                max_length=27,
                null=True,
                verbose_name="Property",
            ),
        ),
    ]



# Generated by Django 3.1.2 on 2020-11-17 23:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0012_change_network_prefixes_and_info_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="networkcontact",
            name="phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=100,
                verbose_name="Phone",
            ),
        ),
        migrations.AlterField(
            model_name="facility",
            name="sales_phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=192,
                verbose_name="Sales Phone",
            ),
        ),
        migrations.AlterField(
            model_name="facility",
            name="tech_phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=192,
                verbose_name="Technical Phone",
            ),
        ),
        migrations.AlterField(
            model_name="internetexchange",
            name="policy_phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=192,
                verbose_name="Policy Phone",
            ),
        ),
        migrations.AlterField(
            model_name="internetexchange",
            name="tech_phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=192,
                verbose_name="Technical Phone",
            ),
        ),
    ]



# Generated by Django 3.2.13 on 2022-06-20 05:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0020_status_dashboard"),
    ]

    operations = [
        migrations.AddField(
            model_name="network",
            name="rir_status",
            field=models.CharField(
                default=None, max_length=255, null=True, verbose_name="RIR status"
            ),
        ),
        migrations.AddField(
            model_name="network",
            name="rir_status_updated",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="RIR status updated"
            ),
        ),
    ]



# Generated by Django 1.11.23 on 2019-12-09 09:06


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="network",
            name="info_prefixes4",
            field=models.PositiveIntegerField(
                blank=True,
                help_text="Recommended IPv4 maximum-prefix limit to be configured on peering sessions for this ASN",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="network",
            name="info_prefixes6",
            field=models.PositiveIntegerField(
                blank=True,
                help_text="Recommended IPv6 maximum-prefix limit to be configured on peering sessions for this ASN",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="network",
            name="irr_as_set",
            field=models.CharField(
                blank=True,
                help_text="Reference to an AS-SET or ROUTE-SET in Internet Routing Registry (IRR)",
                max_length=255,
            ),
        ),
    ]



# Generated by Django 2.2.12 on 2020-04-03 20:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0004_rs_lg_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="facility",
            name="sales_email",
            field=models.EmailField(blank=True, max_length=254),
        ),
        migrations.AddField(
            model_name="facility",
            name="sales_phone",
            field=models.CharField(blank=True, max_length=192),
        ),
        migrations.AddField(
            model_name="facility",
            name="tech_email",
            field=models.EmailField(blank=True, max_length=254),
        ),
        migrations.AddField(
            model_name="facility",
            name="tech_phone",
            field=models.CharField(blank=True, max_length=192),
        ),
    ]



import django.forms
from django.core.exceptions import ValidationError
from django.db import models
from django.utils.translation import gettext_lazy as _


class MultipleChoiceField(models.CharField):

    """
    Field that can take a set of string values
    and store them in a charfield using a delimiter

    This needs to be compatible with django-rest-framework's
    multiple choice field.
    """

    def cleaned_values(self, values):
        return [value.strip("{}' ") for value in values]

    def clean_choices(self, values):
        for value in values:
            exists = False
            for choice, label in self.choices:
                if choice == value:
                    exists = True
                    break

            if not exists:
                raise ValidationError(_("Invalid value: {}").format(value))

    def validate(self, value, model_instance):
        if not self.editable:
            # Skip validation for non-editable fields.
            return

        self.clean_choices(self.cleaned_values(value))

        if value is None and not self.null:
            raise ValidationError(self.error_messages["null"], code="null")

        if not self.blank and value in self.empty_values:
            raise ValidationError(self.error_messages["blank"], code="blank")

    def from_db_value(self, value, expression, connection):

        if value is None:
            return None

        if not value or value == "[]":
            return []

        values = self.cleaned_values(value.split(","))

        self.clean_choices(values)

        return values

    def get_prep_value(self, value):

        if value is None:
            return ""

        picked = []
        for choice, label in self.choices:
            if choice in value:
                picked.append(choice)

        return ",".join(picked)

    def to_python(self, value):
        if isinstance(value, (list, set, tuple)):
            return value

        if value is None:
            return value

        if value == "[]":
            return None

        values = self.cleaned_values(value.split(","))
        self.clean_choices(values)

        return values

    def formfield(self, **kwargs):
        defaults = {"form_class": django.forms.MultipleChoiceField}
        defaults.update(**kwargs)
        return super().formfield(**defaults)

    def value_to_string(self, obj):
        values = self.value_from_object(obj)
        self.clean_choices(self.cleaned_values(values))
        return ",".join(values)



from django.conf import settings as __settings

# import to namespace
from django_peeringdb.models.abstract import *  # noqa

if not __settings.ABSTRACT_ONLY:
    # import to namespace
    from django_peeringdb.models.concrete import *  # noqa

del __settings



from django.core.management.base import BaseCommand


class Command(BaseCommand):
    def handle(self, *args, **options):
        self.stdout.write(
            "In an effort to split sync logic from schema definition, the pdb_sync functionality has been removed from this module."
        )
        self.stdout.write("")
        self.stdout.write(
            "Use the peeringdb client to sync your database going forward."
        )
        self.stdout.write("")
        self.stdout.write("Please find instructions on how to do so at: ")
        self.stdout.write(
            "https://github.com/peeringdb/django-peeringdb/blob/master/docs/sync.md"
        )



# Generated by Django 2.2.12 on 2020-05-01 16:17

import django.db.models.deletion
import django_countries.fields
import django_inet.models
from django.db import migrations, models

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0006_net_operational"),
    ]

    operations = []



from django.contrib import admin

from django_peeringdb.models import (
    Facility,
    InternetExchange,
    InternetExchangeFacility,
    IXLan,
    IXLanPrefix,
    Network,
    NetworkContact,
    NetworkFacility,
    NetworkIXLan,
    Organization,
)


class HandleRefAdminMixIn:
    """Dummy MixIn that just hides HandleRef's fields."""

    exclude = ("status", "version")


class ModelAdminBase(HandleRefAdminMixIn, admin.ModelAdmin):
    def has_change_permission(self, request, obj=None):
        """Make everything read-only, as this is PeeringDB's data."""
        return False


# Organization view
class NetworkInline(HandleRefAdminMixIn, admin.TabularInline):
    model = Network
    fields = ("asn", "name", "aka")
    show_change_link = True


@admin.register(Organization)
class OrganizationAdmin(ModelAdminBase):
    search_fields = ("name",)
    list_display = ("name", "website")
    inlines = [
        NetworkInline,
    ]


# Facility view
@admin.register(Facility)
class FacilityAdmin(ModelAdminBase):
    search_fields = ("name", "address1")
    list_display = ("name", "org", "city", "address1")


# Network views
class NetworkContactInline(HandleRefAdminMixIn, admin.TabularInline):
    model = NetworkContact


class NetworkFacilityInline(HandleRefAdminMixIn, admin.TabularInline):
    model = NetworkFacility


class NetworkIXLanInline(HandleRefAdminMixIn, admin.TabularInline):
    model = NetworkIXLan


@admin.register(Network)
class NetworkAdmin(ModelAdminBase):
    search_fields = ("name", "aka", "asn")
    list_display = ("name", "aka", "asn")
    inlines = [
        NetworkFacilityInline,
        NetworkContactInline,
        NetworkIXLanInline,
    ]


# IX views
class IXLanInline(HandleRefAdminMixIn, admin.StackedInline):
    model = IXLan
    show_change_link = True


class InternetExchangeFacilityInline(HandleRefAdminMixIn, admin.TabularInline):
    model = InternetExchangeFacility


@admin.register(InternetExchange)
class InternetExchangeAdmin(ModelAdminBase):
    search_fields = (
        "name",
        "name_long",
    )
    list_display = ("name", "name_long", "city")
    inlines = [
        InternetExchangeFacilityInline,
        IXLanInline,
    ]


# IXLan views
class IXLanPrefixInline(HandleRefAdminMixIn, admin.StackedInline):
    model = IXLanPrefix


@admin.register(IXLan)
class IXLanAdmin(ModelAdminBase):
    search_fields = ("name", "ix__name")
    list_display = ("__str__", "ix")
    inlines = [
        IXLanPrefixInline,
    ]



# Generated by Django 3.2.7 on 2021-10-02 00:54

import django.core.validators
import django_inet.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0018_add_region_continent_field"),
    ]

    operations = [
        migrations.AddField(
            model_name="internetexchange",
            name="sales_email",
            field=models.EmailField(
                blank=True, max_length=254, verbose_name="Sales Email"
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="sales_phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=192,
                verbose_name="Sales Phone",
            ),
        ),
    ]



from django.conf import settings
from django.core.validators import URLValidator
from django.db import models
from django.utils.translation import gettext_lazy as _
from django_countries.fields import CountryField
from django_handleref.models import HandleRefModel
from django_inet.models import ASNField, IPAddressField, IPPrefixField, MacAddressField

from django_peeringdb import const
from django_peeringdb.fields import MultipleChoiceField


class LG_URLField(models.URLField):
    default_validators = [URLValidator(schemes=["http", "https", "telnet", "ssh"])]

    def __init__(self, *args, **kwargs):
        kwargs["max_length"] = 255
        super().__init__(*args, **kwargs)


class URLField(models.URLField):
    default_validators = [URLValidator(schemes=["http", "https"])]

    def __init__(self, *args, **kwargs):
        kwargs["max_length"] = 255
        super().__init__(*args, **kwargs)


class AddressModel(models.Model):
    """
    Postal Address
    """

    address1 = models.CharField(_("Address 1"), max_length=255, blank=True)
    address2 = models.CharField(_("Address 2"), max_length=255, blank=True)
    city = models.CharField(_("City"), max_length=255, blank=True)
    state = models.CharField(_("State"), max_length=255, blank=True)
    zipcode = models.CharField(_("Zip-Code"), max_length=48, blank=True)
    country = CountryField(_("Country"), blank=True)

    suite = models.CharField(_("Suite"), max_length=255, blank=True)
    floor = models.CharField(_("Floor"), max_length=255, blank=True)

    latitude = models.DecimalField(
        _("Latitude"), max_digits=9, decimal_places=6, blank=True, null=True
    )
    longitude = models.DecimalField(
        _("Longitude"), max_digits=9, decimal_places=6, blank=True, null=True
    )

    class Meta:
        abstract = True

    def __str__(self):
        return self.address1


class OrganizationBase(HandleRefModel, AddressModel):
    name = models.CharField(_("Name"), max_length=255, unique=True)

    aka = models.CharField(_("Also Known As"), max_length=255, blank=True)
    name_long = models.CharField(_("Long Name"), max_length=255, blank=True)

    website = URLField(_("Website"), blank=True)
    notes = models.TextField(_("Notes"), blank=True)

    class Meta:
        abstract = True
        db_table = "%sorganization" % settings.TABLE_PREFIX
        verbose_name = _("Organization")
        verbose_name_plural = _("Organizations")

    class HandleRef:
        tag = "org"
        delete_cascade = ["net_set", "fac_set", "ix_set"]

    def __str__(self):
        return self.name


class FacilityBase(HandleRefModel, AddressModel):
    name = models.CharField(_("Name"), max_length=255, unique=True)
    website = URLField(_("Website"), blank=True)

    aka = models.CharField(_("Also Known As"), max_length=255, blank=True)
    name_long = models.CharField(_("Long Name"), max_length=255, blank=True)

    clli = models.CharField(_("CLLI Code"), max_length=18, blank=True)
    rencode = models.CharField(_("Rencode"), max_length=18, blank=True)
    npanxx = models.CharField(_("NPA-NXX"), max_length=21, blank=True)

    tech_email = models.EmailField(_("Technical Email"), max_length=254, blank=True)
    tech_phone = models.CharField(
        _("Technical Phone"),
        max_length=192,
        blank=True,
        help_text=const.PHONE_HELP_TEXT,
    )
    sales_email = models.EmailField(_("Sales Email"), max_length=254, blank=True)
    sales_phone = models.CharField(
        _("Sales Phone"), max_length=192, blank=True, help_text=const.PHONE_HELP_TEXT
    )

    property = models.CharField(
        _("Property"),
        max_length=27,
        null=True,
        blank=True,
        choices=const.PROPERTY,
        help_text=_(
            "A property owner is the individual or entity that has title to the property. A lessee is a user of a property who has a lease, an agreement, with the owner of the property."
        ),
    )

    diverse_serving_substations = models.BooleanField(
        _("Diverse Serving Substations"),
        null=True,
        blank=True,
        help_text=_(
            "Two separate and distinct paths to individual substations which should maintain a separated path back to one or more utility generator stations."
        ),
    )

    available_voltage_services = MultipleChoiceField(
        _("Available Voltage Services"),
        null=True,
        blank=True,
        max_length=255,
        choices=const.AVAILABLE_VOLTAGE,
        help_text=_(
            "The alternating current voltage available to users of the facility either directly from the landlord or delivered by the utility separately."
        ),
    )

    notes = models.TextField(_("Notes"), blank=True)

    region_continent = models.CharField(
        _("Continental Region"),
        max_length=255,
        choices=const.REGIONS,
        blank=True,
        null=True,
    )

    status_dashboard = URLField(_("Status Dashboard"), null=True, blank=True)

    class Meta:
        abstract = True
        db_table = "%sfacility" % settings.TABLE_PREFIX
        verbose_name = _("Facility")
        verbose_name_plural = _("Facilities")

    class HandleRef:
        tag = "fac"
        delete_cascade = ["ixfac_set", "netfac_set"]

    def __str__(self):
        return self.name


class ContactBase(HandleRefModel):
    role = models.CharField(_("Role"), max_length=27, choices=const.POC_ROLES)
    visible = models.CharField(
        _("Visibility"), max_length=64, choices=const.VISIBILITY, default="Public"
    )
    name = models.CharField(_("Name"), max_length=254, blank=True)
    phone = models.CharField(
        _("Phone"), max_length=100, blank=True, help_text=const.PHONE_HELP_TEXT
    )
    email = models.EmailField(_("Email"), max_length=254, blank=True)
    url = URLField(_("URL"), blank=True)

    class Meta:
        abstract = True
        db_table = "%snetwork_contact" % settings.TABLE_PREFIX
        verbose_name = _("Contact")
        verbose_name_plural = _("Contacts")

    class HandleRef:
        tag = "poc"

    def __str__(self):
        return self.name


class NetworkBase(HandleRefModel):
    asn = ASNField(verbose_name="ASN", unique=True)
    name = models.CharField(_("Name"), max_length=255, unique=True)

    aka = models.CharField(_("Also Known As"), max_length=255, blank=True)
    name_long = models.CharField(_("Long Name"), max_length=255, blank=True)

    irr_as_set = models.CharField(
        _("IRR as-set/route-set"),
        max_length=255,
        blank=True,
        help_text=_(
            "Reference to an AS-SET or "
            "ROUTE-SET in Internet "
            "Routing Registry (IRR)"
        ),
    )
    website = URLField(_("Website"), blank=True)
    looking_glass = LG_URLField(_("Looking Glass URL"), blank=True)
    route_server = LG_URLField(_("Route Server URL"), blank=True)

    notes = models.TextField(_("Notes"), blank=True)
    notes_private = models.TextField(_("Private notes"), blank=True)

    info_traffic = models.CharField(
        _("Traffic Levels"), max_length=39, blank=True, choices=const.TRAFFIC
    )
    info_ratio = models.CharField(
        _("Traffic Ratios"),
        max_length=45,
        blank=True,
        choices=const.RATIOS,
        default="Not Disclosed",
    )
    info_scope = models.CharField(
        _("Geographic Scope"),
        max_length=39,
        blank=True,
        choices=const.SCOPES,
        default="Not Disclosed",
    )
    info_type = models.CharField(
        _("Network Type"),
        max_length=60,
        blank=True,
        choices=const.NET_TYPES,
        default="Not Disclosed",
    )
    info_prefixes4 = models.PositiveIntegerField(
        _("IPv4 Prefixes"),
        null=True,
        blank=True,
        help_text=_(
            "Recommended maximum number of IPv4 "
            "routes/prefixes to be configured on peering "
            "sessions for this ASN"
        ),
    )
    info_prefixes6 = models.PositiveIntegerField(
        _("IPv6 Prefixes"),
        null=True,
        blank=True,
        help_text=_(
            "Recommended maximum number of IPv6 "
            "routes/prefixes to be configured on peering "
            "sessions for this ASN"
        ),
    )
    info_unicast = models.BooleanField(_("Unicast IPv4"), default=False)
    info_multicast = models.BooleanField(_("Multicast"), default=False)
    info_ipv6 = models.BooleanField(_("Unicast IPv6"), default=False)
    info_never_via_route_servers = models.BooleanField(
        _("Never via route servers"),
        default=False,
        help_text=_(
            "Indicates if this network "
            "will announce its routes "
            "via route servers or not"
        ),
    )

    policy_url = URLField(_("Peering Policy"), blank=True)
    policy_general = models.CharField(
        _("General Policy"), max_length=72, blank=True, choices=const.POLICY_GENERAL
    )
    policy_locations = models.CharField(
        _("Multiple Locations"),
        max_length=72,
        blank=True,
        choices=const.POLICY_LOCATIONS,
    )
    policy_ratio = models.BooleanField(_("Ratio Requirement"), default=False)
    policy_contracts = models.CharField(
        _("Contract Requirement"),
        max_length=36,
        blank=True,
        choices=const.POLICY_CONTRACTS,
    )

    status_dashboard = URLField(_("Status Dashboard"), null=True, blank=True)

    rir_status = models.CharField(
        _("RIR status"),
        null=True,
        default=None,
        max_length=255,
    )
    rir_status_updated = models.DateTimeField(
        _("RIR status updated"), blank=True, null=True
    )

    class Meta:
        abstract = True
        db_table = "%snetwork" % settings.TABLE_PREFIX
        verbose_name = _("Network")
        verbose_name_plural = _("Networks")

    class HandleRef:
        tag = "net"
        delete_cascade = ["poc_set", "netfac_set", "netixlan_set"]

    def __str__(self):
        return self.name


class InternetExchangeBase(HandleRefModel):
    name = models.CharField(_("Name"), max_length=64, unique=True)

    aka = models.CharField(_("Also Known As"), max_length=255, blank=True)
    name_long = models.CharField(_("Long Name"), max_length=255, blank=True)

    city = models.CharField(_("City"), max_length=192)
    country = CountryField(_("Country"))

    notes = models.TextField(_("Notes"), blank=True)

    region_continent = models.CharField(
        _("Continental Region"), max_length=255, choices=const.REGIONS
    )
    media = models.CharField(_("Media Type"), max_length=128, choices=const.MEDIA)
    proto_unicast = models.BooleanField(_("Unicast IPv4"), default=False)
    proto_multicast = models.BooleanField(_("Multicast"), default=False)
    proto_ipv6 = models.BooleanField(_("Unicast IPv6"), default=False)

    website = URLField(_("Company Website"), blank=True)
    url_stats = URLField(_("Traffic Stats Website"), blank=True)

    tech_email = models.EmailField(_("Technical Email"), max_length=254, blank=True)
    tech_phone = models.CharField(
        _("Technical Phone"),
        max_length=192,
        blank=True,
        help_text=const.PHONE_HELP_TEXT,
    )
    policy_email = models.EmailField(_("Policy Email"), max_length=254, blank=True)
    policy_phone = models.CharField(
        _("Policy Phone"), max_length=192, blank=True, help_text=const.PHONE_HELP_TEXT
    )

    sales_email = models.EmailField(_("Sales Email"), max_length=254, blank=True)
    sales_phone = models.CharField(
        _("Sales Phone"), max_length=192, blank=True, help_text=const.PHONE_HELP_TEXT
    )

    ixf_net_count = models.IntegerField(_("IX-F Network Count"), default=0)
    ixf_last_import = models.DateTimeField(_("IX-F Last Import"), null=True, blank=True)

    service_level = models.CharField(
        _("Service Level"),
        max_length=60,
        blank=True,
        choices=const.SERVICE_LEVEL_TYPES,
        default="Not Disclosed",
    )

    terms = models.CharField(
        _("Terms"),
        max_length=60,
        blank=True,
        choices=const.TERMS_TYPES,
        default="Not Disclosed",
    )

    status_dashboard = URLField(_("Status Dashboard"), null=True, blank=True)

    class Meta:
        abstract = True
        db_table = "%six" % settings.TABLE_PREFIX
        verbose_name = _("Internet Exchange")
        verbose_name_plural = _("Internet Exchanges")

    class HandleRef:
        tag = "ix"
        delete_cascade = ["ixfac_set", "ixlan_set"]

    def __str__(self):
        return self.name


class InternetExchangeFacilityBase(HandleRefModel):
    class Meta:
        abstract = True
        db_table = "%six_facility" % settings.TABLE_PREFIX
        verbose_name = _("Internet Exchange facility")
        verbose_name_plural = _("Internet Exchange facilities")

    class HandleRef:
        tag = "ixfac"


class IXLanBase(HandleRefModel):
    name = models.CharField(_("Name"), max_length=255, blank=True)
    descr = models.TextField(_("Description"), blank=True)
    mtu = models.PositiveIntegerField("MTU", null=True, blank=True)
    vlan = models.PositiveIntegerField("VLAN", null=True, blank=True)
    dot1q_support = models.BooleanField("802.1Q", default=False)
    rs_asn = ASNField(
        verbose_name=_("Route Server ASN"), null=True, blank=True, default=0
    )
    arp_sponge = MacAddressField(
        verbose_name=_("ARP sponging MAC"), null=True, unique=True, blank=True
    )

    ixf_ixp_member_list_url = models.URLField(
        verbose_name=_("IX-F Member Export URL"), null=True, blank=True
    )
    ixf_ixp_member_list_url_visible = models.CharField(
        verbose_name=_("IX-F Member Export URL Visibility"),
        max_length=64,
        choices=const.VISIBILITY,
        default="Private",
    )

    class Meta:
        abstract = True
        db_table = "%sixlan" % settings.TABLE_PREFIX
        verbose_name = _("Internet Exchange LAN")
        verbose_name_plural = _("Internet Exchange LANs")

    class HandleRef:
        tag = "ixlan"
        delete_cascade = ["ixpfx_set", "netixlan_set"]


class IXLanPrefixBase(HandleRefModel):
    notes = models.CharField(_("Notes"), max_length=255, blank=True)
    protocol = models.CharField(_("Protocol"), max_length=64, choices=const.PROTOCOLS)
    prefix = IPPrefixField(verbose_name=_("Prefix"), unique=True)
    in_dfz = models.BooleanField(default=False)

    class Meta:
        abstract = True
        db_table = "%sixlan_prefix" % settings.TABLE_PREFIX
        verbose_name = _("Internet Exchange LAN prefix")
        verbose_name_plural = _("Internet Exchange LAN prefixes")

    class HandleRef:
        tag = "ixpfx"


class NetworkFacilityBase(HandleRefModel):
    local_asn = ASNField(verbose_name=_("Local ASN"), null=True, blank=True)
    avail_sonet = models.BooleanField("SONET", default=False)
    avail_ethernet = models.BooleanField("Ethernet", default=False)
    avail_atm = models.BooleanField("ATM", default=False)

    class Meta:
        abstract = True
        db_table = "%snetwork_facility" % settings.TABLE_PREFIX
        verbose_name = _("Network Facility")
        verbose_name_plural = _("Network Facilities")

    class HandleRef:
        tag = "netfac"


class NetworkIXLanBase(HandleRefModel):
    asn = ASNField(verbose_name="ASN")
    ipaddr4 = IPAddressField(verbose_name="IPv4", version=4, blank=True, null=True)
    ipaddr6 = IPAddressField(verbose_name="IPv6", version=6, blank=True, null=True)
    is_rs_peer = models.BooleanField(_("RS peer"), default=False)
    notes = models.CharField(_("Notes"), max_length=255, blank=True)
    speed = models.PositiveIntegerField(_("Speed (mbit/sec)"))
    operational = models.BooleanField(_("Operational"), default=True)

    class Meta:
        abstract = True
        db_table = "%snetwork_ixlan" % settings.TABLE_PREFIX
        verbose_name = _("Public Peering Exchange Point")
        verbose_name_plural = _("Public Peering Exchange Points")

    class HandleRef:
        tag = "netixlan"



# Generated by Django 1.11.7 on 2018-10-08 23:07


import django.db.models.deletion
import django.db.models.manager
import django_countries.fields
import django_handleref.models
import django_inet.models
from django.db import migrations, models

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Facility",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(blank=True, max_length=255, verbose_name="Status"),
                ),
                (
                    "created",
                    django_handleref.models.CreatedDateTimeField(
                        auto_now_add=True, verbose_name="Created"
                    ),
                ),
                (
                    "updated",
                    django_handleref.models.UpdatedDateTimeField(
                        auto_now=True, verbose_name="Updated"
                    ),
                ),
                ("version", models.IntegerField(default=0)),
                ("address1", models.CharField(blank=True, max_length=255)),
                ("address2", models.CharField(blank=True, max_length=255)),
                ("city", models.CharField(blank=True, max_length=255)),
                ("state", models.CharField(blank=True, max_length=255)),
                ("zipcode", models.CharField(blank=True, max_length=48)),
                (
                    "country",
                    django_countries.fields.CountryField(blank=True, max_length=2),
                ),
                (
                    "latitude",
                    models.DecimalField(
                        blank=True,
                        decimal_places=6,
                        help_text="Latitude",
                        max_digits=9,
                        null=True,
                    ),
                ),
                (
                    "longitude",
                    models.DecimalField(
                        blank=True,
                        decimal_places=6,
                        help_text="Longitude",
                        max_digits=9,
                        null=True,
                    ),
                ),
                ("name", models.CharField(max_length=255, unique=True)),
                (
                    "website",
                    django_peeringdb.models.abstract.URLField(
                        blank=True, max_length=255
                    ),
                ),
                ("clli", models.CharField(blank=True, max_length=18)),
                ("rencode", models.CharField(blank=True, max_length=18)),
                ("npanxx", models.CharField(blank=True, max_length=21)),
                ("notes", models.TextField(blank=True)),
            ],
            options={
                "abstract": False,
                "db_table": "peeringdb_facility",
                "verbose_name_plural": "Facilities",
            },
            managers=[
                ("handleref", django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name="InternetExchange",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(blank=True, max_length=255, verbose_name="Status"),
                ),
                (
                    "created",
                    django_handleref.models.CreatedDateTimeField(
                        auto_now_add=True, verbose_name="Created"
                    ),
                ),
                (
                    "updated",
                    django_handleref.models.UpdatedDateTimeField(
                        auto_now=True, verbose_name="Updated"
                    ),
                ),
                ("version", models.IntegerField(default=0)),
                ("name", models.CharField(max_length=64, unique=True)),
                ("name_long", models.CharField(blank=True, max_length=254)),
                ("city", models.CharField(max_length=192)),
                ("country", django_countries.fields.CountryField(max_length=2)),
                ("notes", models.TextField(blank=True)),
                (
                    "region_continent",
                    models.CharField(
                        choices=[
                            ("North America", "North America"),
                            ("Asia Pacific", "Asia Pacific"),
                            ("Europe", "Europe"),
                            ("South America", "South America"),
                            ("Africa", "Africa"),
                            ("Australia", "Australia"),
                            ("Middle East", "Middle East"),
                        ],
                        max_length=255,
                    ),
                ),
                (
                    "media",
                    models.CharField(
                        choices=[
                            ("Ethernet", "Ethernet"),
                            ("ATM", "ATM"),
                            ("Multiple", "Multiple"),
                        ],
                        max_length=128,
                    ),
                ),
                ("proto_unicast", models.BooleanField(default=False)),
                ("proto_multicast", models.BooleanField(default=False)),
                ("proto_ipv6", models.BooleanField(default=False)),
                (
                    "website",
                    django_peeringdb.models.abstract.URLField(
                        blank=True, max_length=255
                    ),
                ),
                (
                    "url_stats",
                    django_peeringdb.models.abstract.URLField(
                        blank=True, max_length=255
                    ),
                ),
                ("tech_email", models.EmailField(blank=True, max_length=254)),
                ("tech_phone", models.CharField(blank=True, max_length=192)),
                ("policy_email", models.EmailField(blank=True, max_length=254)),
                ("policy_phone", models.CharField(blank=True, max_length=192)),
            ],
            options={
                "abstract": False,
                "db_table": "peeringdb_ix",
            },
            managers=[
                ("handleref", django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name="InternetExchangeFacility",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(blank=True, max_length=255, verbose_name="Status"),
                ),
                (
                    "created",
                    django_handleref.models.CreatedDateTimeField(
                        auto_now_add=True, verbose_name="Created"
                    ),
                ),
                (
                    "updated",
                    django_handleref.models.UpdatedDateTimeField(
                        auto_now=True, verbose_name="Updated"
                    ),
                ),
                ("version", models.IntegerField(default=0)),
                (
                    "fac",
                    models.ForeignKey(
                        default=0,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="ixfac_set",
                        to="django_peeringdb.Facility",
                    ),
                ),
                (
                    "ix",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="ixfac_set",
                        to="django_peeringdb.InternetExchange",
                    ),
                ),
            ],
            options={
                "db_table": "peeringdb_ix_facility",
            },
            managers=[
                ("handleref", django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name="IXLan",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(blank=True, max_length=255, verbose_name="Status"),
                ),
                (
                    "created",
                    django_handleref.models.CreatedDateTimeField(
                        auto_now_add=True, verbose_name="Created"
                    ),
                ),
                (
                    "updated",
                    django_handleref.models.UpdatedDateTimeField(
                        auto_now=True, verbose_name="Updated"
                    ),
                ),
                ("version", models.IntegerField(default=0)),
                ("name", models.CharField(blank=True, max_length=255)),
                ("descr", models.TextField(blank=True)),
                ("mtu", models.PositiveIntegerField(blank=True, null=True)),
                ("vlan", models.PositiveIntegerField(blank=True, null=True)),
                ("dot1q_support", models.BooleanField(default=False)),
                (
                    "rs_asn",
                    django_inet.models.ASNField(blank=True, default=0, null=True),
                ),
                (
                    "arp_sponge",
                    django_inet.models.MacAddressField(
                        blank=True, max_length=17, null=True, unique=True
                    ),
                ),
                (
                    "ix",
                    models.ForeignKey(
                        default=0,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="ixlan_set",
                        to="django_peeringdb.InternetExchange",
                    ),
                ),
            ],
            options={
                "abstract": False,
                "db_table": "peeringdb_ixlan",
            },
            managers=[
                ("handleref", django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name="IXLanPrefix",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(blank=True, max_length=255, verbose_name="Status"),
                ),
                (
                    "created",
                    django_handleref.models.CreatedDateTimeField(
                        auto_now_add=True, verbose_name="Created"
                    ),
                ),
                (
                    "updated",
                    django_handleref.models.UpdatedDateTimeField(
                        auto_now=True, verbose_name="Updated"
                    ),
                ),
                ("version", models.IntegerField(default=0)),
                ("notes", models.CharField(blank=True, max_length=255)),
                (
                    "protocol",
                    models.CharField(
                        choices=[("IPv4", "IPv4"), ("IPv6", "IPv6")], max_length=64
                    ),
                ),
                (
                    "prefix",
                    django_inet.models.IPPrefixField(max_length=43, unique=True),
                ),
                (
                    "ixlan",
                    models.ForeignKey(
                        default=0,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="ixpfx_set",
                        to="django_peeringdb.IXLan",
                    ),
                ),
            ],
            options={
                "abstract": False,
                "db_table": "peeringdb_ixlan_prefix",
            },
            managers=[
                ("handleref", django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name="Network",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(blank=True, max_length=255, verbose_name="Status"),
                ),
                (
                    "created",
                    django_handleref.models.CreatedDateTimeField(
                        auto_now_add=True, verbose_name="Created"
                    ),
                ),
                (
                    "updated",
                    django_handleref.models.UpdatedDateTimeField(
                        auto_now=True, verbose_name="Updated"
                    ),
                ),
                ("version", models.IntegerField(default=0)),
                ("asn", django_inet.models.ASNField(unique=True)),
                ("name", models.CharField(max_length=255, unique=True)),
                ("aka", models.CharField(blank=True, max_length=255)),
                ("irr_as_set", models.CharField(blank=True, max_length=255)),
                (
                    "website",
                    django_peeringdb.models.abstract.URLField(
                        blank=True, max_length=255
                    ),
                ),
                (
                    "looking_glass",
                    django_peeringdb.models.abstract.URLField(
                        blank=True, max_length=255
                    ),
                ),
                (
                    "route_server",
                    django_peeringdb.models.abstract.URLField(
                        blank=True, max_length=255
                    ),
                ),
                ("notes", models.TextField(blank=True)),
                ("notes_private", models.TextField(blank=True)),
                (
                    "info_traffic",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("", "Not Disclosed"),
                            ("0-20 Mbps", "0-20 Mbps"),
                            ("20-100Mbps", "20-100Mbps"),
                            ("100-1000Mbps", "100-1000Mbps"),
                            ("1-5Gbps", "1-5Gbps"),
                            ("5-10Gbps", "5-10Gbps"),
                            ("10-20Gbps", "10-20Gbps"),
                            ("20-50 Gbps", "20-50 Gbps"),
                            ("50-100 Gbps", "50-100 Gbps"),
                            ("100+ Gbps", "100+ Gbps"),
                            ("100-200 Gbps", "100-200 Gbps"),
                            ("200-300 Gbps", "200-300 Gbps"),
                            ("300-500 Gbps", "300-500 Gbps"),
                            ("500-1000 Gbps", "500-1000 Gbps"),
                            ("1 Tbps+", "1 Tbps+"),
                            ("10 Tbps+", "10 Tbps+"),
                        ],
                        max_length=39,
                    ),
                ),
                (
                    "info_ratio",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("", "Not Disclosed"),
                            ("Not Disclosed", "Not Disclosed"),
                            ("Heavy Outbound", "Heavy Outbound"),
                            ("Mostly Outbound", "Mostly Outbound"),
                            ("Balanced", "Balanced"),
                            ("Mostly Inbound", "Mostly Inbound"),
                            ("Heavy Inbound", "Heavy Inbound"),
                        ],
                        default="Not Disclosed",
                        max_length=45,
                    ),
                ),
                (
                    "info_scope",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("", "Not Disclosed"),
                            ("Not Disclosed", "Not Disclosed"),
                            ("Regional", "Regional"),
                            ("North America", "North America"),
                            ("Asia Pacific", "Asia Pacific"),
                            ("Europe", "Europe"),
                            ("South America", "South America"),
                            ("Africa", "Africa"),
                            ("Australia", "Australia"),
                            ("Middle East", "Middle East"),
                            ("Global", "Global"),
                        ],
                        default="Not Disclosed",
                        max_length=39,
                    ),
                ),
                (
                    "info_type",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("", "Not Disclosed"),
                            ("Not Disclosed", "Not Disclosed"),
                            ("NSP", "NSP"),
                            ("Content", "Content"),
                            ("Cable/DSL/ISP", "Cable/DSL/ISP"),
                            ("Enterprise", "Enterprise"),
                            ("Educational/Research", "Educational/Research"),
                            ("Non-Profit", "Non-Profit"),
                            ("Route Server", "Route Server"),
                        ],
                        default="Not Disclosed",
                        max_length=60,
                    ),
                ),
                ("info_prefixes4", models.PositiveIntegerField(blank=True, null=True)),
                ("info_prefixes6", models.PositiveIntegerField(blank=True, null=True)),
                ("info_unicast", models.BooleanField(default=False)),
                ("info_multicast", models.BooleanField(default=False)),
                ("info_ipv6", models.BooleanField(default=False)),
                (
                    "policy_url",
                    django_peeringdb.models.abstract.URLField(
                        blank=True, max_length=255
                    ),
                ),
                (
                    "policy_general",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("Open", "Open"),
                            ("Selective", "Selective"),
                            ("Restrictive", "Restrictive"),
                            ("No", "No"),
                        ],
                        max_length=72,
                    ),
                ),
                (
                    "policy_locations",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("Not Required", "Not Required"),
                            ("Preferred", "Preferred"),
                            ("Required - US", "Required - US"),
                            ("Required - EU", "Required - EU"),
                            ("Required - International", "Required - International"),
                        ],
                        max_length=72,
                    ),
                ),
                ("policy_ratio", models.BooleanField(default=False)),
                (
                    "policy_contracts",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("Not Required", "Not Required"),
                            ("Private Only", "Private Only"),
                            ("Required", "Required"),
                        ],
                        max_length=36,
                    ),
                ),
            ],
            options={
                "abstract": False,
                "db_table": "peeringdb_network",
                "verbose_name_plural": "Networks",
            },
            managers=[
                ("handleref", django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name="NetworkContact",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(blank=True, max_length=255, verbose_name="Status"),
                ),
                (
                    "created",
                    django_handleref.models.CreatedDateTimeField(
                        auto_now_add=True, verbose_name="Created"
                    ),
                ),
                (
                    "updated",
                    django_handleref.models.UpdatedDateTimeField(
                        auto_now=True, verbose_name="Updated"
                    ),
                ),
                ("version", models.IntegerField(default=0)),
                (
                    "role",
                    models.CharField(
                        choices=[
                            ("Abuse", "Abuse"),
                            ("Maintenance", "Maintenance"),
                            ("Policy", "Policy"),
                            ("Technical", "Technical"),
                            ("NOC", "NOC"),
                            ("Public Relations", "Public Relations"),
                            ("Sales", "Sales"),
                        ],
                        max_length=27,
                    ),
                ),
                (
                    "visible",
                    models.CharField(
                        choices=[
                            ("Private", "Private"),
                            ("Users", "Users"),
                            ("Public", "Public"),
                        ],
                        default="Public",
                        max_length=64,
                    ),
                ),
                ("name", models.CharField(blank=True, max_length=254)),
                ("phone", models.CharField(blank=True, max_length=100)),
                ("email", models.EmailField(blank=True, max_length=254)),
                (
                    "url",
                    django_peeringdb.models.abstract.URLField(
                        blank=True, max_length=255
                    ),
                ),
                (
                    "net",
                    models.ForeignKey(
                        default=0,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="poc_set",
                        to="django_peeringdb.Network",
                    ),
                ),
            ],
            options={
                "abstract": False,
                "db_table": "peeringdb_network_contact",
            },
            managers=[
                ("handleref", django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name="NetworkFacility",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(blank=True, max_length=255, verbose_name="Status"),
                ),
                (
                    "created",
                    django_handleref.models.CreatedDateTimeField(
                        auto_now_add=True, verbose_name="Created"
                    ),
                ),
                (
                    "updated",
                    django_handleref.models.UpdatedDateTimeField(
                        auto_now=True, verbose_name="Updated"
                    ),
                ),
                ("version", models.IntegerField(default=0)),
                ("local_asn", django_inet.models.ASNField(blank=True, null=True)),
                ("avail_sonet", models.BooleanField(default=False)),
                ("avail_ethernet", models.BooleanField(default=False)),
                ("avail_atm", models.BooleanField(default=False)),
                (
                    "fac",
                    models.ForeignKey(
                        default=0,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="netfac_set",
                        to="django_peeringdb.Facility",
                    ),
                ),
                (
                    "net",
                    models.ForeignKey(
                        default=0,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="netfac_set",
                        to="django_peeringdb.Network",
                    ),
                ),
            ],
            options={
                "db_table": "peeringdb_network_facility",
            },
            managers=[
                ("handleref", django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name="NetworkIXLan",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(blank=True, max_length=255, verbose_name="Status"),
                ),
                (
                    "created",
                    django_handleref.models.CreatedDateTimeField(
                        auto_now_add=True, verbose_name="Created"
                    ),
                ),
                (
                    "updated",
                    django_handleref.models.UpdatedDateTimeField(
                        auto_now=True, verbose_name="Updated"
                    ),
                ),
                ("version", models.IntegerField(default=0)),
                ("asn", django_inet.models.ASNField()),
                (
                    "ipaddr4",
                    django_inet.models.IPAddressField(
                        blank=True, max_length=39, null=True
                    ),
                ),
                (
                    "ipaddr6",
                    django_inet.models.IPAddressField(
                        blank=True, max_length=39, null=True
                    ),
                ),
                ("is_rs_peer", models.BooleanField(default=False)),
                ("notes", models.CharField(blank=True, max_length=255)),
                ("speed", models.PositiveIntegerField()),
                (
                    "ixlan",
                    models.ForeignKey(
                        default=0,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="netixlan_set",
                        to="django_peeringdb.IXLan",
                    ),
                ),
                (
                    "net",
                    models.ForeignKey(
                        default=0,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="netixlan_set",
                        to="django_peeringdb.Network",
                    ),
                ),
            ],
            options={
                "abstract": False,
                "db_table": "peeringdb_network_ixlan",
            },
            managers=[
                ("handleref", django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name="Organization",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(blank=True, max_length=255, verbose_name="Status"),
                ),
                (
                    "created",
                    django_handleref.models.CreatedDateTimeField(
                        auto_now_add=True, verbose_name="Created"
                    ),
                ),
                (
                    "updated",
                    django_handleref.models.UpdatedDateTimeField(
                        auto_now=True, verbose_name="Updated"
                    ),
                ),
                ("version", models.IntegerField(default=0)),
                ("address1", models.CharField(blank=True, max_length=255)),
                ("address2", models.CharField(blank=True, max_length=255)),
                ("city", models.CharField(blank=True, max_length=255)),
                ("state", models.CharField(blank=True, max_length=255)),
                ("zipcode", models.CharField(blank=True, max_length=48)),
                (
                    "country",
                    django_countries.fields.CountryField(blank=True, max_length=2),
                ),
                (
                    "latitude",
                    models.DecimalField(
                        blank=True,
                        decimal_places=6,
                        help_text="Latitude",
                        max_digits=9,
                        null=True,
                    ),
                ),
                (
                    "longitude",
                    models.DecimalField(
                        blank=True,
                        decimal_places=6,
                        help_text="Longitude",
                        max_digits=9,
                        null=True,
                    ),
                ),
                ("name", models.CharField(max_length=255, unique=True)),
                (
                    "website",
                    django_peeringdb.models.abstract.URLField(
                        blank=True, max_length=255
                    ),
                ),
                ("notes", models.TextField(blank=True)),
            ],
            options={
                "abstract": False,
                "db_table": "peeringdb_organization",
                "verbose_name_plural": "Organizations",
            },
            managers=[
                ("handleref", django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name="network",
            name="org",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="net_set",
                to="django_peeringdb.Organization",
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="org",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="ix_set",
                to="django_peeringdb.Organization",
            ),
        ),
        migrations.AddField(
            model_name="facility",
            name="org",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="fac_set",
                to="django_peeringdb.Organization",
            ),
        ),
        migrations.AlterUniqueTogether(
            name="networkfacility",
            unique_together={("net", "fac", "local_asn")},
        ),
        migrations.AlterUniqueTogether(
            name="internetexchangefacility",
            unique_together={("ix", "fac")},
        ),
    ]



# Generated by Django 3.1.2 on 2021-03-05 18:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0014_add_suite_and_floor"),
    ]

    operations = [
        # Facilities need "name_long" and "aka"
        migrations.AddField(
            model_name="facility",
            name="aka",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Also Known As"
            ),
        ),
        migrations.AddField(
            model_name="facility",
            name="name_long",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Long Name"
            ),
        ),
        # Internet Exchange already has "name_long," although we alter the max_length
        migrations.AlterField(
            model_name="internetexchange",
            name="name_long",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Long Name"
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="aka",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Also Known As"
            ),
        ),
        # Network already has "aka"
        migrations.AddField(
            model_name="network",
            name="name_long",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Long Name"
            ),
        ),
        # Organization needs "aka" and "name_long"
        migrations.AddField(
            model_name="organization",
            name="aka",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Also Known As"
            ),
        ),
        migrations.AddField(
            model_name="organization",
            name="name_long",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Long Name"
            ),
        ),
    ]



from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _

from django_peeringdb.models import (
    ContactBase,
    FacilityBase,
    InternetExchangeBase,
    InternetExchangeFacilityBase,
    IXLanBase,
    IXLanPrefixBase,
    NetworkBase,
    NetworkFacilityBase,
    NetworkIXLanBase,
    OrganizationBase,
)

all_models = []
tag_dict = {}


def expose_model(cls):
    all_models.append(cls)
    tag_dict[cls._handleref.tag] = cls
    return cls


class URLField(models.URLField):
    """
    local defaults for URLField
    """

    def __init__(self, *args, **kwargs):
        kwargs["max_length"] = 255
        super().__init__(*args, **kwargs)


@expose_model
class Organization(OrganizationBase):
    pass


@expose_model
class Facility(FacilityBase):
    org = models.ForeignKey(
        Organization,
        related_name="fac_set",
        verbose_name=_("Organization"),
        on_delete=models.CASCADE,
    )


@expose_model
class Network(NetworkBase):
    org = models.ForeignKey(
        Organization,
        related_name="net_set",
        verbose_name=_("Organization"),
        on_delete=models.CASCADE,
    )


@expose_model
class InternetExchange(InternetExchangeBase):
    org = models.ForeignKey(
        Organization,
        related_name="ix_set",
        verbose_name=_("Organization"),
        on_delete=models.CASCADE,
    )

    @property
    def fac_set(self):
        return [ixfac.fac for ixfac in self.ixfac_set]


@expose_model
class InternetExchangeFacility(InternetExchangeFacilityBase):
    ix = models.ForeignKey(
        InternetExchange,
        related_name="ixfac_set",
        verbose_name=_("Internet Exchange"),
        on_delete=models.CASCADE,
    )
    fac = models.ForeignKey(
        Facility,
        default=0,
        related_name="ixfac_set",
        verbose_name=_("Facility"),
        on_delete=models.CASCADE,
    )

    class Meta(InternetExchangeFacilityBase.Meta):
        unique_together = ("ix", "fac")
        db_table = "%six_facility" % settings.TABLE_PREFIX

    def __str__(self):
        return f"{self.ix} @ {self.fac}"


@expose_model
class IXLan(IXLanBase):
    ix = models.ForeignKey(
        InternetExchange,
        default=0,
        related_name="ixlan_set",
        verbose_name=_("Internet Exchange"),
        on_delete=models.CASCADE,
    )

    def __str__(self):
        return str(self.ix)


@expose_model
class IXLanPrefix(IXLanPrefixBase):
    ixlan = models.ForeignKey(
        IXLan,
        default=0,
        related_name="ixpfx_set",
        verbose_name=_("Internet Exchange LAN"),
        on_delete=models.CASCADE,
    )

    def __str__(self):
        return f"{self.prefix} @ {self.ixlan}"


@expose_model
class NetworkContact(ContactBase):
    net = models.ForeignKey(
        Network,
        default=0,
        related_name="poc_set",
        verbose_name=_("Network"),
        on_delete=models.CASCADE,
    )

    def __str__(self):
        return f"{self.name}, {self.net} {self.role}"


@expose_model
class NetworkFacility(NetworkFacilityBase):
    net = models.ForeignKey(
        Network,
        default=0,
        related_name="netfac_set",
        verbose_name=_("Network"),
        on_delete=models.CASCADE,
    )
    fac = models.ForeignKey(
        Facility,
        default=0,
        related_name="netfac_set",
        verbose_name=_("Facility"),
        on_delete=models.CASCADE,
    )

    class Meta(NetworkFacilityBase.Meta):
        unique_together = ("net", "fac", "local_asn")
        db_table = "%snetwork_facility" % settings.TABLE_PREFIX

    def __str__(self):
        return f"{self.net} @ {self.fac}"


@expose_model
class NetworkIXLan(NetworkIXLanBase):
    net = models.ForeignKey(
        Network,
        default=0,
        related_name="netixlan_set",
        verbose_name=_("Network"),
        on_delete=models.CASCADE,
    )
    ixlan = models.ForeignKey(
        IXLan,
        default=0,
        related_name="netixlan_set",
        verbose_name=_("Internet Exchange LAN"),
        on_delete=models.CASCADE,
    )

    def __str__(self):
        return f"{self.net} @ {self.ixlan}"


__all__ = [m.__name__ for m in all_models]
# other required vars
__all__.append("all_models")
__all__.append("tag_dict")



# lazy init for translations
from django.utils.translation import gettext_lazy as _

TABLE_PREFIX = "peeringdb_"
ABSTRACT_ONLY = False

DEBUG = False
TEMPLATE_DEBUG = True

INSTALLED_APPS = [
    "django_peeringdb",
]
DATABASES = {"default": {"ENGINE": "django.db.backends.sqlite3", "NAME": ":memory:"}}

LOGGING = {
    "version": 1,
    "disable_existing_loggers": False,
    "filters": {"dev_warnings": {}},
    "handlers": {
        "stderr": {
            "level": "DEBUG",
            "class": "logging.StreamHandler",
            "filters": ["dev_warnings"],
        },
    },
    "loggers": {
        "": {"handlers": ["stderr"], "level": "DEBUG", "propagate": False},
    },
}
USE_TZ = False
TIME_ZONE = "UTC"
# add user defined iso code for Kosovo
COUNTRIES_OVERRIDE = {
    "XK": _("Kosovo"),
}



# Generated by Django 2.2.12 on 2020-07-13 07:00

import django.db.models.deletion
import django_countries.fields
import django_inet.models
from django.db import migrations, models

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0010_ix_ixf_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="ixlan",
            name="ixf_ixp_member_list_url",
            field=models.URLField(
                blank=True, null=True, verbose_name="IX-F Member Export URL"
            ),
        ),
        migrations.AddField(
            model_name="ixlan",
            name="ixf_ixp_member_list_url_visible",
            field=models.CharField(
                choices=[
                    ("Private", "Private"),
                    ("Users", "Users"),
                    ("Public", "Public"),
                ],
                default="Private",
                max_length=64,
                verbose_name="IX-F Member Export URL Visibility",
            ),
        ),
    ]



# Generated by Django 3.2.7 on 2021-09-21 15:50

import django.core.validators
import django_inet.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0017_facility_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="facility",
            name="region_continent",
            field=models.CharField(
                blank=True,
                choices=[
                    ("North America", "North America"),
                    ("Asia Pacific", "Asia Pacific"),
                    ("Europe", "Europe"),
                    ("South America", "South America"),
                    ("Africa", "Africa"),
                    ("Australia", "Australia"),
                    ("Middle East", "Middle East"),
                ],
                max_length=255,
                null=True,
                verbose_name="Continental Region",
            ),
        ),
    ]



from django.utils.translation import gettext_lazy as _

MEDIA = (("Ethernet", _("Ethernet")), ("ATM", _("ATM")), ("Multiple", _("Multiple")))

POC_ROLES = (
    ("Abuse", _("Abuse")),
    ("Maintenance", _("Maintenance")),
    ("Policy", _("Policy")),
    ("Technical", _("Technical")),
    ("NOC", _("NOC")),
    ("Public Relations", _("Public Relations")),
    ("Sales", _("Sales")),
)

POLICY_GENERAL = (
    ("Open", _("Open")),
    ("Selective", _("Selective")),
    ("Restrictive", _("Restrictive")),
    ("No", _("No")),
)

POLICY_LOCATIONS = (
    ("Not Required", _("Not Required")),
    ("Preferred", _("Preferred")),
    ("Required - US", _("Required - US")),
    ("Required - EU", _("Required - EU")),
    ("Required - International", _("Required - International")),
)

POLICY_CONTRACTS = (
    ("Not Required", _("Not Required")),
    ("Private Only", _("Private Only")),
    ("Required", _("Required")),
)

PROTOCOLS = (
    ("IPv4", _("IPv4")),
    ("IPv6", _("IPv6")),
)

RATIOS = (
    ("", _("Not Disclosed")),
    ("Not Disclosed", _("Not Disclosed")),
    ("Heavy Outbound", _("Heavy Outbound")),
    ("Mostly Outbound", _("Mostly Outbound")),
    ("Balanced", _("Balanced")),
    ("Mostly Inbound", _("Mostly Inbound")),
    ("Heavy Inbound", _("Heavy Inbound")),
)

REGIONS = (
    ("North America", _("North America")),
    ("Asia Pacific", _("Asia Pacific")),
    ("Europe", _("Europe")),
    ("South America", _("South America")),
    ("Africa", _("Africa")),
    ("Australia", _("Australia")),
    ("Middle East", _("Middle East")),
)

SCOPES = (
    ("", _("Not Disclosed")),
    ("Not Disclosed", _("Not Disclosed")),
    ("Regional", _("Regional")),
    ("North America", _("North America")),
    ("Asia Pacific", _("Asia Pacific")),
    ("Europe", _("Europe")),
    ("South America", _("South America")),
    ("Africa", _("Africa")),
    ("Australia", _("Australia")),
    ("Middle East", _("Middle East")),
    ("Global", _("Global")),
)

TRAFFIC = (
    ("", _("Not Disclosed")),
    ("0-20Mbps", _("0-20Mbps")),
    ("20-100Mbps", _("20-100Mbps")),
    ("100-1000Mbps", _("100-1000Mbps")),
    ("1-5Gbps", _("1-5Gbps")),
    ("5-10Gbps", _("5-10Gbps")),
    ("10-20Gbps", _("10-20Gbps")),
    ("20-50Gbps", _("20-50Gbps")),
    ("50-100Gbps", _("50-100Gbps")),
    ("100-200Gbps", _("100-200Gbps")),
    ("200-300Gbps", _("200-300Gbps")),
    ("300-500Gbps", _("300-500Gbps")),
    ("500-1000Gbps", _("500-1000Gbps")),
    ("1-5Tbps", _("1-5Tbps")),
    ("5-10Tbps", _("5-10Tbps")),
    ("10-20Tbps", _("10-20Tbps")),
    ("20-50Tbps", _("20-50Tbps")),
    ("50-100Tbps", _("50-100Tbps")),
    ("100+Tbps", _("100+Tbps")),
)

NET_TYPES = (
    ("", _("Not Disclosed")),
    ("Not Disclosed", _("Not Disclosed")),
    ("NSP", _("NSP")),
    ("Content", _("Content")),
    ("Cable/DSL/ISP", _("Cable/DSL/ISP")),
    ("Enterprise", _("Enterprise")),
    ("Educational/Research", _("Educational/Research")),
    ("Non-Profit", _("Non-Profit")),
    ("Route Server", _("Route Server")),
    ("Network Services", _("Network Services")),
    ("Route Collector", _("Route Collector")),
    ("Government", _("Government")),
)

VISIBILITY = (
    ("Private", _("Private")),
    #                   ('Peers', _('Peers')),
    ("Users", _("Users")),
    ("Public", _("Public")),
)


PHONE_HELP_TEXT = _(
    "An E.164-formatted phone number starts with a +, "
    "followed by the country code, then the national phone number "
    "(dropping the leading 0 in most countries), without spaces "
    "or dashes between the groups of digits"
)

SERVICE_LEVEL_TYPES = (
    ("", _("Not Disclosed")),
    ("Not Disclosed", _("Not Disclosed")),
    ("Best Effort (no SLA)", _("Best Effort (no SLA)")),
    ("Normal Business Hours", _("Normal Business Hours")),
    ("24/7 Support", _("24/7 Support")),
)

TERMS_TYPES = (
    ("", _("Not Disclosed")),
    ("Not Disclosed", _("Not Disclosed")),
    ("No Commercial Terms", _("No Commercial Terms")),
    ("Bundled With Other Services", _("Bundled With Other Services")),
    ("Non-recurring Fees Only", _("Non-recurring Fees Only")),
    ("Recurring Fees", _("Recurring Fees")),
)

PROPERTY = (("", _("Not Disclosed")), ("Owner", _("Owner")), ("Lessee", _("Lessee")))

AVAILABLE_VOLTAGE = (
    ("48 VDC", _("48 VDC")),
    ("120 VAC", _("120 VAC")),
    ("208 VAC", _("208 VAC")),
    ("240 VAC", _("240 VAC")),
    ("480 VAC", _("480 VAC")),
)

REGION_MAPPING = [
    {
        "code": "AD",
        "continent": "Europe",
    },
    {
        "code": "AF",
        "continent": "Asia Pacific",
    },
    {
        "code": "AG",
        "continent": "North America",
    },
    {
        "code": "AL",
        "continent": "Europe",
    },
    {
        "code": "AM",
        "continent": "Asia Pacific",
    },
    {
        "code": "AO",
        "continent": "Africa",
    },
    {
        "code": "AR",
        "continent": "South America",
    },
    {
        "code": "AT",
        "continent": "Europe",
    },
    {
        "code": "AU",
        "continent": "Australia",
    },
    {
        "code": "AZ",
        "continent": "Asia Pacific",
    },
    {
        "code": "BB",
        "continent": "North America",
    },
    {
        "code": "BD",
        "continent": "Asia Pacific",
    },
    {
        "code": "BE",
        "continent": "Europe",
    },
    {
        "code": "BF",
        "continent": "Africa",
    },
    {
        "code": "BG",
        "continent": "Europe",
    },
    {
        "code": "BH",
        "continent": "Middle East",
    },
    {
        "code": "BI",
        "continent": "Africa",
    },
    {
        "code": "BJ",
        "continent": "Africa",
    },
    {
        "code": "BN",
        "continent": "Asia Pacific",
    },
    {
        "code": "BO",
        "continent": "South America",
    },
    {
        "code": "BR",
        "continent": "South America",
    },
    {
        "code": "BS",
        "continent": "North America",
    },
    {
        "code": "BT",
        "continent": "Asia Pacific",
    },
    {
        "code": "BW",
        "continent": "Africa",
    },
    {
        "code": "BY",
        "continent": "Europe",
    },
    {
        "code": "BZ",
        "continent": "North America",
    },
    {
        "code": "CA",
        "continent": "North America",
    },
    {
        "code": "CD",
        "continent": "Africa",
    },
    {
        "code": "CG",
        "continent": "Africa",
    },
    {
        "code": "CI",
        "continent": "Africa",
    },
    {
        "code": "CL",
        "continent": "South America",
    },
    {
        "code": "CM",
        "continent": "Africa",
    },
    {
        "code": "CN",
        "continent": "Asia Pacific",
    },
    {
        "code": "CO",
        "continent": "South America",
    },
    {
        "code": "CR",
        "continent": "North America",
    },
    {
        "code": "CU",
        "continent": "North America",
    },
    {
        "code": "CV",
        "continent": "Africa",
    },
    {
        "code": "CY",
        "continent": "Middle East",
    },
    {
        "code": "CZ",
        "continent": "Europe",
    },
    {
        "code": "DE",
        "continent": "Europe",
    },
    {
        "code": "DJ",
        "continent": "Africa",
    },
    {
        "code": "DK",
        "continent": "Europe",
    },
    {
        "code": "DM",
        "continent": "North America",
    },
    {
        "code": "DO",
        "continent": "North America",
    },
    {
        "code": "EC",
        "continent": "South America",
    },
    {
        "code": "EE",
        "continent": "Europe",
    },
    {
        "code": "EG",
        "continent": "MIddle East",
    },
    {
        "code": "ER",
        "continent": "Africa",
    },
    {
        "code": "ET",
        "continent": "Africa",
    },
    {
        "code": "FI",
        "continent": "Europe",
    },
    {
        "code": "FJ",
        "continent": "Asia Pacific",
    },
    {
        "code": "FR",
        "continent": "Europe",
    },
    {
        "code": "GA",
        "continent": "Africa",
    },
    {
        "code": "GE",
        "continent": "Asia Pacific",
    },
    {
        "code": "GH",
        "continent": "Africa",
    },
    {
        "code": "GM",
        "continent": "Africa",
    },
    {
        "code": "GN",
        "continent": "Africa",
    },
    {
        "code": "GR",
        "continent": "Europe",
    },
    {
        "code": "GT",
        "continent": "North America",
    },
    {
        "code": "HT",
        "continent": "North America",
    },
    {
        "code": "GW",
        "continent": "Africa",
    },
    {
        "code": "GY",
        "continent": "South America",
    },
    {
        "code": "HN",
        "continent": "North America",
    },
    {
        "code": "HU",
        "continent": "Europe",
    },
    {
        "code": "ID",
        "continent": "Asia Pacific",
    },
    {
        "code": "IE",
        "continent": "Europe",
    },
    {
        "code": "IL",
        "continent": "Middle East",
    },
    {
        "code": "IN",
        "continent": "Asia Pacific",
    },
    {
        "code": "IQ",
        "continent": "Middle East",
    },
    {
        "code": "IR",
        "continent": "Middle East",
    },
    {
        "code": "IS",
        "continent": "Europe",
    },
    {
        "code": "IT",
        "continent": "Europe",
    },
    {
        "code": "JM",
        "continent": "North America",
    },
    {
        "code": "JO",
        "continent": "Middle East",
    },
    {
        "code": "JP",
        "continent": "Asia Pacific",
    },
    {
        "code": "KE",
        "continent": "Africa",
    },
    {
        "code": "KG",
        "continent": "Asia Pacific",
    },
    {
        "code": "KI",
        "continent": "Asia Pacific",
    },
    {
        "code": "KP",
        "continent": "Asia Pacific",
    },
    {
        "code": "KR",
        "continent": "Asia Pacific",
    },
    {
        "code": "KW",
        "continent": "Middle East",
    },
    {
        "code": "LB",
        "continent": "Middle East",
    },
    {
        "code": "LI",
        "continent": "Europe",
    },
    {
        "code": "LR",
        "continent": "Africa",
    },
    {
        "code": "LS",
        "continent": "Africa",
    },
    {
        "code": "LT",
        "continent": "Europe",
    },
    {
        "code": "LU",
        "continent": "Europe",
    },
    {
        "code": "LV",
        "continent": "Europe",
    },
    {
        "code": "LY",
        "continent": "Africa",
    },
    {
        "code": "MG",
        "continent": "Africa",
    },
    {
        "code": "MH",
        "continent": "Asia Pacific",
    },
    {
        "code": "MK",
        "continent": "Europe",
    },
    {
        "code": "ML",
        "continent": "Africa",
    },
    {
        "code": "MM",
        "continent": "Asia Pacific",
    },
    {
        "code": "MN",
        "continent": "Asia Pacific",
    },
    {
        "code": "MR",
        "continent": "Africa",
    },
    {
        "code": "MT",
        "continent": "Europe",
    },
    {
        "code": "MU",
        "continent": "Africa",
    },
    {
        "code": "MV",
        "continent": "Asia Pacific",
    },
    {
        "code": "MW",
        "continent": "Africa",
    },
    {
        "code": "MX",
        "continent": "North America",
    },
    {
        "code": "MY",
        "continent": "Asia Pacific",
    },
    {
        "code": "MZ",
        "continent": "Africa",
    },
    {
        "code": "NA",
        "continent": "Africa",
    },
    {
        "code": "NE",
        "continent": "Africa",
    },
    {
        "code": "NG",
        "continent": "Africa",
    },
    {
        "code": "NI",
        "continent": "North America",
    },
    {
        "code": "NL",
        "continent": "Europe",
    },
    {
        "code": "NO",
        "continent": "Europe",
    },
    {
        "code": "NP",
        "continent": "Asia Pacific",
    },
    {
        "code": "NR",
        "continent": "Asia Pacific",
    },
    {
        "code": "NZ",
        "continent": "Asia Pacific",
    },
    {
        "code": "OM",
        "continent": "Middle East",
    },
    {
        "code": "PA",
        "continent": "North America",
    },
    {
        "code": "PE",
        "continent": "South America",
    },
    {
        "code": "PG",
        "continent": "Asia Pacific",
    },
    {
        "code": "PH",
        "continent": "Asia Pacific",
    },
    {
        "code": "PK",
        "continent": "Asia Pacific",
    },
    {
        "code": "PL",
        "continent": "Europe",
    },
    {
        "code": "PT",
        "continent": "Europe",
    },
    {
        "code": "PW",
        "continent": "Asia Pacific",
    },
    {
        "code": "PY",
        "continent": "South America",
    },
    {
        "code": "QA",
        "continent": "Middle East",
    },
    {
        "code": "RO",
        "continent": "Europe",
    },
    {
        "code": "RU",
        "continent": "Europe",
    },
    {
        "code": "RW",
        "continent": "Africa",
    },
    {
        "code": "SA",
        "continent": "Middle East",
    },
    {
        "code": "SB",
        "continent": "Asia Pacific",
    },
    {
        "code": "SC",
        "continent": "Africa",
    },
    {
        "code": "SD",
        "continent": "Africa",
    },
    {
        "code": "SE",
        "continent": "Europe",
    },
    {
        "code": "SG",
        "continent": "Asia Pacific",
    },
    {
        "code": "SI",
        "continent": "Europe",
    },
    {
        "code": "SK",
        "continent": "Europe",
    },
    {
        "code": "SL",
        "continent": "Africa",
    },
    {
        "code": "SM",
        "continent": "Europe",
    },
    {
        "code": "SN",
        "continent": "Africa",
    },
    {
        "code": "SO",
        "continent": "Africa",
    },
    {
        "code": "SR",
        "continent": "South America",
    },
    {
        "code": "ST",
        "continent": "Africa",
    },
    {
        "code": "SY",
        "continent": "Middle East",
    },
    {
        "code": "TG",
        "continent": "Africa",
    },
    {
        "code": "TH",
        "continent": "Asia Pacific",
    },
    {
        "code": "TJ",
        "continent": "Asia Pacific",
    },
    {
        "code": "TM",
        "continent": "Asia Pacific",
    },
    {
        "code": "TN",
        "continent": "Africa",
    },
    {
        "code": "TO",
        "continent": "Asia Pacific",
    },
    {
        "code": "TR",
        "continent": "Middle East",
    },
    {
        "code": "TT",
        "continent": "North America",
    },
    {
        "code": "TV",
        "continent": "Asia Pacific",
    },
    {
        "code": "TZ",
        "continent": "Africa",
    },
    {
        "code": "UA",
        "continent": "Europe",
    },
    {
        "code": "UG",
        "continent": "Africa",
    },
    {
        "code": "US",
        "continent": "North America",
    },
    {
        "code": "UY",
        "continent": "South America",
    },
    {
        "code": "UZ",
        "continent": "Asia Pacific",
    },
    {
        "code": "VA",
        "continent": "Europe",
    },
    {
        "code": "VE",
        "continent": "South America",
    },
    {
        "code": "VN",
        "continent": "Asia Pacific",
    },
    {
        "code": "VU",
        "continent": "Asia Pacific",
    },
    {
        "code": "YE",
        "continent": "Middle East",
    },
    {
        "code": "ZM",
        "continent": "Africa",
    },
    {
        "code": "ZW",
        "continent": "Africa",
    },
    {
        "code": "DZ",
        "continent": "Africa",
    },
    {
        "code": "BA",
        "continent": "Europe",
    },
    {
        "code": "KH",
        "continent": "Asia Pacific",
    },
    {
        "code": "CF",
        "continent": "Africa",
    },
    {
        "code": "TD",
        "continent": "Africa",
    },
    {
        "code": "KM",
        "continent": "Africa",
    },
    {
        "code": "HR",
        "continent": "Europe",
    },
    {
        "code": "TL",
        "continent": "Asia Pacific",
    },
    {
        "code": "SV",
        "continent": "North America",
    },
    {
        "code": "GQ",
        "continent": "Africa",
    },
    {
        "code": "GD",
        "continent": "North America",
    },
    {
        "code": "KZ",
        "continent": "Asia Pacific",
    },
    {
        "code": "LA",
        "continent": "Asia Pacific",
    },
    {
        "code": "FM",
        "continent": "Asia Pacific",
    },
    {
        "code": "MD",
        "continent": "Europe",
    },
    {
        "code": "MC",
        "continent": "Europe",
    },
    {
        "code": "ME",
        "continent": "Europe",
    },
    {
        "code": "MA",
        "continent": "Africa",
    },
    {
        "code": "KN",
        "continent": "North America",
    },
    {
        "code": "LC",
        "continent": "North America",
    },
    {
        "code": "VC",
        "continent": "North America",
    },
    {
        "code": "WS",
        "continent": "Asia Pacific",
    },
    {
        "code": "RS",
        "continent": "Europe",
    },
    {
        "code": "ZA",
        "continent": "Africa",
    },
    {
        "code": "ES",
        "continent": "Europe",
    },
    {
        "code": "LK",
        "continent": "Asia Pacific",
    },
    {
        "code": "SZ",
        "continent": "Africa",
    },
    {
        "code": "CH",
        "continent": "Europe",
    },
    {
        "code": "AE",
        "continent": "Middle East",
    },
    {
        "code": "GB",
        "continent": "Europe",
    },
    {
        "code": "TW",
        "continent": "Asia Pacific",
    },
    {
        "code": "HK",
        "continent": "Asia Pacific",
    },
    {
        "code": "XK",
        "continent": "Europe",
    },
    {
        "code": "PR",
        "continent": "America",
    },
]



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['django_peeringdb',
 'django_peeringdb.admin',
 'django_peeringdb.client_adaptor',
 'django_peeringdb.management',
 'django_peeringdb.management.commands',
 'django_peeringdb.migrations',
 'django_peeringdb.models']

package_data = \
{'': ['*']}

install_requires = \
['django_countries>1', 'django_handleref>=1,<2', 'django_inet>=1,<2']

entry_points = \
{'markdown.extensions': ['pymdgen = pymdgen.md:Extension']}

setup_kwargs = {
    'name': 'django-peeringdb',
    'version': '2.14.0',
    'description': 'PeeringDB Django models',
    'long_description': '\n# django-peeringdb\n\n[![PyPI](https://img.shields.io/pypi/v/django_peeringdb.svg?maxAge=2592000)](https://pypi.python.org/pypi/django_peeringdb)\n[![PyPI](https://img.shields.io/pypi/pyversions/django-peeringdb.svg)](https://pypi.python.org/pypi/django-peeringdb)\n[![Tests](https://github.com/peeringdb/django-peeringdb/workflows/tests/badge.svg)](https://github.com/peeringdb/django-peeringdb/actions/workflows/tests.yml)\n[![LGTM Grade](https://img.shields.io/lgtm/grade/python/github/peeringdb/django-peeringdb)](https://lgtm.com/projects/g/peeringdb/django-peeringdb/alerts/)\n[![Codecov](https://img.shields.io/codecov/c/github/peeringdb/django-peeringdb/master.svg?maxAge=2592000)](https://codecov.io/github/peeringdb/django-peeringdb)\n\nDjango models for PeeringDB\n\nSee the docs at http://peeringdb.github.io/django-peeringdb/\n\n',
    'author': 'PeeringDB',
    'author_email': 'support@peeringdb.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/peeringdb/django-peeringdb',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from django import setup
from django.conf import global_settings, settings

from django_peeringdb import default_settings


# default_settings must define _all_ defaults, so we have to extract and combine
# everything from global_settings and django_peeringdb's defaults.
# https://docs.djangoproject.com/en/dev/topics/settings/#custom-default-settings
class _Settings:
    def __init__(self):
        self.__dict__ = {}

    def update(self, new):
        for name in dir(new):
            if name.isupper():
                self.__dict__[name] = getattr(new, name)


def configure(**kwargs):
    if settings.configured:
        return

    defaults = _Settings()
    defaults.update(global_settings)
    defaults.update(default_settings)
    settings.configure(default_settings=defaults, **kwargs)
    setup()



# Generated by Django 2.2.12 on 2020-04-03 20:40

from django.db import migrations

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0003_never_via_route_servers"),
    ]

    operations = [
        migrations.AlterField(
            model_name="network",
            name="looking_glass",
            field=django_peeringdb.models.abstract.LG_URLField(
                blank=True, max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="network",
            name="route_server",
            field=django_peeringdb.models.abstract.LG_URLField(
                blank=True, max_length=255
            ),
        ),
    ]



# Generated by Django 2.2.12 on 2020-07-10 13:33

import django.db.models.deletion
import django_countries.fields
import django_inet.models
from django.db import migrations, models

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0009_ixlanprefix_in_dfz"),
    ]

    operations = [
        migrations.AddField(
            model_name="internetexchange",
            name="ixf_last_import",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="IX-F Last Import"
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="ixf_net_count",
            field=models.IntegerField(default=0, verbose_name="IX-F Network Count"),
        ),
    ]



DJANGO_DB_FIELDS = (
    "ENGINE",
    "NAME",
    "HOST",
    "PORT",
    "USER",
    "PASSWORD",
)


def database_settings(db_config):
    db = {}
    for k, v in list(db_config.items()):
        k = k.upper()
        if k in DJANGO_DB_FIELDS:
            db[k] = v

    db["ENGINE"] = "django.db.backends." + db["ENGINE"]
    return db


__backend = None


def load_backend(**orm_config):
    """
    Load the client adaptor module of django_peeringdb
    Assumes config is valid.
    """
    settings = {}
    settings["SECRET_KEY"] = orm_config.get("secret_key", "")

    db_config = orm_config["database"]
    if db_config:
        settings["DATABASES"] = {"default": database_settings(db_config)}

    from django_peeringdb.client_adaptor.setup import configure

    # Override defaults
    configure(**settings)
    # Must import implementation module after configure
    from django_peeringdb.client_adaptor import backend

    migrate = orm_config.get("migrate")
    if migrate and not backend.Backend().is_database_migrated():
        backend.Backend().migrate_database()

    return backend



# Generated by Django 3.1.2 on 2020-11-23 21:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0013_add_phone_help_text"),
    ]

    operations = [
        migrations.AddField(
            model_name="facility",
            name="floor",
            field=models.CharField(blank=True, max_length=255, verbose_name="Floor"),
        ),
        migrations.AddField(
            model_name="facility",
            name="suite",
            field=models.CharField(blank=True, max_length=255, verbose_name="Suite"),
        ),
        migrations.AddField(
            model_name="organization",
            name="floor",
            field=models.CharField(blank=True, max_length=255, verbose_name="Floor"),
        ),
        migrations.AddField(
            model_name="organization",
            name="suite",
            field=models.CharField(blank=True, max_length=255, verbose_name="Suite"),
        ),
    ]



# Generated by Django 2.2.12 on 2020-05-13 08:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0008_traffic_levels"),
    ]

    operations = [
        migrations.AddField(
            model_name="ixlanprefix",
            name="in_dfz",
            field=models.BooleanField(default=False),
        ),
    ]
